import typing

import typing_extensions

_list = list

@typing.type_check_only
class AbsoluteDateRange(typing_extensions.TypedDict, total=False):
    endDate: Date
    startDate: Date

@typing.type_check_only
class AcceptProposalRequest(typing_extensions.TypedDict, total=False):
    proposalRevision: str

@typing.type_check_only
class AdSize(typing_extensions.TypedDict, total=False):
    height: str
    sizeType: typing_extensions.Literal[
        "SIZE_TYPE_UNSPECIFIED", "PIXEL", "INTERSTITIAL", "NATIVE", "FLUID"
    ]
    width: str

@typing.type_check_only
class AdTechnologyProviders(typing_extensions.TypedDict, total=False):
    detectedProviderIds: _list[str]
    hasUnidentifiedProvider: bool

@typing.type_check_only
class AddDealAssociationRequest(typing_extensions.TypedDict, total=False):
    association: CreativeDealAssociation

@typing.type_check_only
class AddNoteRequest(typing_extensions.TypedDict, total=False):
    note: Note

@typing.type_check_only
class AppContext(typing_extensions.TypedDict, total=False):
    appTypes: _list[str]

@typing.type_check_only
class AuctionContext(typing_extensions.TypedDict, total=False):
    auctionTypes: _list[str]

@typing.type_check_only
class BidMetricsRow(typing_extensions.TypedDict, total=False):
    bids: MetricValue
    bidsInAuction: MetricValue
    billedImpressions: MetricValue
    impressionsWon: MetricValue
    measurableImpressions: MetricValue
    reachedQueries: MetricValue
    rowDimensions: RowDimensions
    viewableImpressions: MetricValue

@typing.type_check_only
class BidResponseWithoutBidsStatusRow(typing_extensions.TypedDict, total=False):
    impressionCount: MetricValue
    rowDimensions: RowDimensions
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "RESPONSES_WITHOUT_BIDS",
        "RESPONSES_WITHOUT_BIDS_FOR_ACCOUNT",
        "RESPONSES_WITHOUT_BIDS_FOR_DEAL",
    ]

@typing.type_check_only
class Buyer(typing_extensions.TypedDict, total=False):
    accountId: str

@typing.type_check_only
class CalloutStatusRow(typing_extensions.TypedDict, total=False):
    calloutStatusId: int
    impressionCount: MetricValue
    rowDimensions: RowDimensions

@typing.type_check_only
class CancelNegotiationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Client(typing_extensions.TypedDict, total=False):
    clientAccountId: str
    clientName: str
    entityId: str
    entityName: str
    entityType: typing_extensions.Literal[
        "ENTITY_TYPE_UNSPECIFIED",
        "ADVERTISER",
        "BRAND",
        "AGENCY",
        "ENTITY_TYPE_UNCLASSIFIED",
    ]
    partnerClientId: str
    role: typing_extensions.Literal[
        "CLIENT_ROLE_UNSPECIFIED",
        "CLIENT_DEAL_VIEWER",
        "CLIENT_DEAL_NEGOTIATOR",
        "CLIENT_DEAL_APPROVER",
    ]
    status: typing_extensions.Literal["CLIENT_STATUS_UNSPECIFIED", "DISABLED", "ACTIVE"]
    visibleToSeller: bool

@typing.type_check_only
class ClientUser(typing_extensions.TypedDict, total=False):
    clientAccountId: str
    email: str
    status: typing_extensions.Literal[
        "USER_STATUS_UNSPECIFIED", "PENDING", "ACTIVE", "DISABLED"
    ]
    userId: str

@typing.type_check_only
class ClientUserInvitation(typing_extensions.TypedDict, total=False):
    clientAccountId: str
    email: str
    invitationId: str

@typing.type_check_only
class CompleteSetupRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ContactInformation(typing_extensions.TypedDict, total=False):
    email: str
    name: str

@typing.type_check_only
class Correction(typing_extensions.TypedDict, total=False):
    contexts: _list[ServingContext]
    details: _list[str]
    type: typing_extensions.Literal[
        "CORRECTION_TYPE_UNSPECIFIED",
        "VENDOR_IDS_ADDED",
        "SSL_ATTRIBUTE_REMOVED",
        "FLASH_FREE_ATTRIBUTE_REMOVED",
        "FLASH_FREE_ATTRIBUTE_ADDED",
        "REQUIRED_ATTRIBUTE_ADDED",
        "REQUIRED_VENDOR_ADDED",
        "SSL_ATTRIBUTE_ADDED",
        "IN_BANNER_VIDEO_ATTRIBUTE_ADDED",
        "MRAID_ATTRIBUTE_ADDED",
        "FLASH_ATTRIBUTE_REMOVED",
        "VIDEO_IN_SNIPPET_ATTRIBUTE_ADDED",
    ]

@typing.type_check_only
class Creative(typing_extensions.TypedDict, total=False):
    accountId: str
    adChoicesDestinationUrl: str
    adTechnologyProviders: AdTechnologyProviders
    advertiserName: str
    agencyId: str
    apiUpdateTime: str
    attributes: _list[str]
    clickThroughUrls: _list[str]
    corrections: _list[Correction]
    creativeId: str
    dealsStatus: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "NOT_CHECKED",
        "CONDITIONALLY_APPROVED",
        "APPROVED",
        "DISAPPROVED",
        "PENDING_REVIEW",
        "STATUS_TYPE_UNSPECIFIED",
    ]
    declaredClickThroughUrls: _list[str]
    detectedAdvertiserIds: _list[str]
    detectedDomains: _list[str]
    detectedLanguages: _list[str]
    detectedProductCategories: _list[int]
    detectedSensitiveCategories: _list[int]
    html: HtmlContent
    impressionTrackingUrls: _list[str]
    native: NativeContent
    openAuctionStatus: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "NOT_CHECKED",
        "CONDITIONALLY_APPROVED",
        "APPROVED",
        "DISAPPROVED",
        "PENDING_REVIEW",
        "STATUS_TYPE_UNSPECIFIED",
    ]
    restrictedCategories: _list[str]
    servingRestrictions: _list[ServingRestriction]
    vendorIds: _list[int]
    version: int
    video: VideoContent

@typing.type_check_only
class CreativeDealAssociation(typing_extensions.TypedDict, total=False):
    accountId: str
    creativeId: str
    dealsId: str

@typing.type_check_only
class CreativeRestrictions(typing_extensions.TypedDict, total=False):
    creativeFormat: typing_extensions.Literal[
        "CREATIVE_FORMAT_UNSPECIFIED", "DISPLAY", "VIDEO"
    ]
    creativeSpecifications: _list[CreativeSpecification]
    skippableAdType: typing_extensions.Literal[
        "SKIPPABLE_AD_TYPE_UNSPECIFIED", "SKIPPABLE", "INSTREAM_SELECT", "NOT_SKIPPABLE"
    ]

@typing.type_check_only
class CreativeSize(typing_extensions.TypedDict, total=False):
    allowedFormats: _list[str]
    companionSizes: _list[Size]
    creativeSizeType: typing_extensions.Literal[
        "CREATIVE_SIZE_TYPE_UNSPECIFIED", "REGULAR", "INTERSTITIAL", "VIDEO", "NATIVE"
    ]
    nativeTemplate: typing_extensions.Literal[
        "UNKNOWN_NATIVE_TEMPLATE",
        "NATIVE_CONTENT_AD",
        "NATIVE_APP_INSTALL_AD",
        "NATIVE_VIDEO_CONTENT_AD",
        "NATIVE_VIDEO_APP_INSTALL_AD",
    ]
    size: Size
    skippableAdType: typing_extensions.Literal[
        "SKIPPABLE_AD_TYPE_UNSPECIFIED", "GENERIC", "INSTREAM_SELECT", "NOT_SKIPPABLE"
    ]

@typing.type_check_only
class CreativeSpecification(typing_extensions.TypedDict, total=False):
    creativeCompanionSizes: _list[AdSize]
    creativeSize: AdSize

@typing.type_check_only
class CreativeStatusRow(typing_extensions.TypedDict, total=False):
    bidCount: MetricValue
    creativeStatusId: int
    rowDimensions: RowDimensions

@typing.type_check_only
class CriteriaTargeting(typing_extensions.TypedDict, total=False):
    excludedCriteriaIds: _list[str]
    targetedCriteriaIds: _list[str]

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class DayPart(typing_extensions.TypedDict, total=False):
    dayOfWeek: typing_extensions.Literal[
        "DAY_OF_WEEK_UNSPECIFIED",
        "MONDAY",
        "TUESDAY",
        "WEDNESDAY",
        "THURSDAY",
        "FRIDAY",
        "SATURDAY",
        "SUNDAY",
    ]
    endTime: TimeOfDay
    startTime: TimeOfDay

@typing.type_check_only
class DayPartTargeting(typing_extensions.TypedDict, total=False):
    dayParts: _list[DayPart]
    timeZoneType: typing_extensions.Literal[
        "TIME_ZONE_SOURCE_UNSPECIFIED", "PUBLISHER", "USER"
    ]

@typing.type_check_only
class Deal(typing_extensions.TypedDict, total=False):
    availableEndTime: str
    availableStartTime: str
    buyerPrivateData: PrivateData
    createProductId: str
    createProductRevision: str
    createTime: str
    creativePreApprovalPolicy: typing_extensions.Literal[
        "CREATIVE_PRE_APPROVAL_POLICY_UNSPECIFIED",
        "SELLER_PRE_APPROVAL_REQUIRED",
        "SELLER_PRE_APPROVAL_NOT_REQUIRED",
    ]
    creativeRestrictions: CreativeRestrictions
    creativeSafeFrameCompatibility: typing_extensions.Literal[
        "CREATIVE_SAFE_FRAME_COMPATIBILITY_UNSPECIFIED", "COMPATIBLE", "INCOMPATIBLE"
    ]
    dealId: str
    dealServingMetadata: DealServingMetadata
    dealTerms: DealTerms
    deliveryControl: DeliveryControl
    description: str
    displayName: str
    externalDealId: str
    isSetupComplete: bool
    programmaticCreativeSource: typing_extensions.Literal[
        "PROGRAMMATIC_CREATIVE_SOURCE_UNSPECIFIED", "ADVERTISER", "PUBLISHER"
    ]
    proposalId: str
    sellerContacts: _list[ContactInformation]
    syndicationProduct: typing_extensions.Literal[
        "SYNDICATION_PRODUCT_UNSPECIFIED", "CONTENT", "MOBILE", "VIDEO", "GAMES"
    ]
    targeting: MarketplaceTargeting
    targetingCriterion: _list[TargetingCriteria]
    updateTime: str
    webPropertyCode: str

@typing.type_check_only
class DealPauseStatus(typing_extensions.TypedDict, total=False):
    buyerPauseReason: str
    firstPausedBy: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    hasBuyerPaused: bool
    hasSellerPaused: bool
    sellerPauseReason: str

@typing.type_check_only
class DealServingMetadata(typing_extensions.TypedDict, total=False):
    dealPauseStatus: DealPauseStatus

@typing.type_check_only
class DealTerms(typing_extensions.TypedDict, total=False):
    brandingType: typing_extensions.Literal[
        "BRANDING_TYPE_UNSPECIFIED", "BRANDED", "SEMI_TRANSPARENT"
    ]
    description: str
    estimatedGrossSpend: Price
    estimatedImpressionsPerDay: str
    guaranteedFixedPriceTerms: GuaranteedFixedPriceTerms
    nonGuaranteedAuctionTerms: NonGuaranteedAuctionTerms
    nonGuaranteedFixedPriceTerms: NonGuaranteedFixedPriceTerms
    sellerTimeZone: str

@typing.type_check_only
class DeliveryControl(typing_extensions.TypedDict, total=False):
    creativeBlockingLevel: typing_extensions.Literal[
        "CREATIVE_BLOCKING_LEVEL_UNSPECIFIED",
        "PUBLISHER_BLOCKING_RULES",
        "ADX_POLICY_BLOCKING_ONLY",
    ]
    deliveryRateType: typing_extensions.Literal[
        "DELIVERY_RATE_TYPE_UNSPECIFIED",
        "EVENLY",
        "FRONT_LOADED",
        "AS_FAST_AS_POSSIBLE",
    ]
    frequencyCaps: _list[FrequencyCap]

@typing.type_check_only
class Disapproval(typing_extensions.TypedDict, total=False):
    details: _list[str]
    reason: typing_extensions.Literal[
        "LENGTH_OF_IMAGE_ANIMATION",
        "BROKEN_URL",
        "MEDIA_NOT_FUNCTIONAL",
        "INVALID_FOURTH_PARTY_CALL",
        "INCORRECT_REMARKETING_DECLARATION",
        "LANDING_PAGE_ERROR",
        "AD_SIZE_DOES_NOT_MATCH_AD_SLOT",
        "NO_BORDER",
        "FOURTH_PARTY_BROWSER_COOKIES",
        "LSO_OBJECTS",
        "BLANK_CREATIVE",
        "DESTINATION_URLS_UNDECLARED",
        "PROBLEM_WITH_CLICK_MACRO",
        "INCORRECT_AD_TECHNOLOGY_DECLARATION",
        "INCORRECT_DESTINATION_URL_DECLARATION",
        "EXPANDABLE_INCORRECT_DIRECTION",
        "EXPANDABLE_DIRECTION_NOT_SUPPORTED",
        "EXPANDABLE_INVALID_VENDOR",
        "EXPANDABLE_FUNCTIONALITY",
        "VIDEO_INVALID_VENDOR",
        "VIDEO_UNSUPPORTED_LENGTH",
        "VIDEO_UNSUPPORTED_FORMAT",
        "VIDEO_FUNCTIONALITY",
        "LANDING_PAGE_DISABLED",
        "MALWARE_SUSPECTED",
        "ADULT_IMAGE_OR_VIDEO",
        "INACCURATE_AD_TEXT",
        "COUNTERFEIT_DESIGNER_GOODS",
        "POP_UP",
        "INVALID_RTB_PROTOCOL_USAGE",
        "RAW_IP_ADDRESS_IN_SNIPPET",
        "UNACCEPTABLE_CONTENT_SOFTWARE",
        "UNAUTHORIZED_COOKIE_ON_GOOGLE_DOMAIN",
        "UNDECLARED_FLASH_OBJECTS",
        "INVALID_SSL_DECLARATION",
        "DIRECT_DOWNLOAD_IN_AD",
        "MAXIMUM_DOWNLOAD_SIZE_EXCEEDED",
        "DESTINATION_URL_SITE_NOT_CRAWLABLE",
        "BAD_URL_LEGAL_DISAPPROVAL",
        "PHARMA_GAMBLING_ALCOHOL_NOT_ALLOWED",
        "DYNAMIC_DNS_AT_DESTINATION_URL",
        "POOR_IMAGE_OR_VIDEO_QUALITY",
        "UNACCEPTABLE_IMAGE_CONTENT",
        "INCORRECT_IMAGE_LAYOUT",
        "IRRELEVANT_IMAGE_OR_VIDEO",
        "DESTINATION_SITE_DOES_NOT_ALLOW_GOING_BACK",
        "MISLEADING_CLAIMS_IN_AD",
        "RESTRICTED_PRODUCTS",
        "UNACCEPTABLE_CONTENT",
        "AUTOMATED_AD_CLICKING",
        "INVALID_URL_PROTOCOL",
        "UNDECLARED_RESTRICTED_CONTENT",
        "INVALID_REMARKETING_LIST_USAGE",
        "DESTINATION_SITE_NOT_CRAWLABLE_ROBOTS_TXT",
        "CLICK_TO_DOWNLOAD_NOT_AN_APP",
        "INACCURATE_REVIEW_EXTENSION",
        "SEXUALLY_EXPLICIT_CONTENT",
        "GAINING_AN_UNFAIR_ADVANTAGE",
        "GAMING_THE_GOOGLE_NETWORK",
        "DANGEROUS_PRODUCTS_KNIVES",
        "DANGEROUS_PRODUCTS_EXPLOSIVES",
        "DANGEROUS_PRODUCTS_GUNS",
        "DANGEROUS_PRODUCTS_DRUGS",
        "DANGEROUS_PRODUCTS_TOBACCO",
        "DANGEROUS_PRODUCTS_WEAPONS",
        "UNCLEAR_OR_IRRELEVANT_AD",
        "PROFESSIONAL_STANDARDS",
        "DYSFUNCTIONAL_PROMOTION",
        "INVALID_INTEREST_BASED_AD",
        "MISUSE_OF_PERSONAL_INFORMATION",
        "OMISSION_OF_RELEVANT_INFORMATION",
        "UNAVAILABLE_PROMOTIONS",
        "MISLEADING_PROMOTIONS",
        "INAPPROPRIATE_CONTENT",
        "SENSITIVE_EVENTS",
        "SHOCKING_CONTENT",
        "ENABLING_DISHONEST_BEHAVIOR",
        "TECHNICAL_REQUIREMENTS",
        "RESTRICTED_POLITICAL_CONTENT",
        "UNSUPPORTED_CONTENT",
        "INVALID_BIDDING_METHOD",
        "VIDEO_TOO_LONG",
        "VIOLATES_JAPANESE_PHARMACY_LAW",
        "UNACCREDITED_PET_PHARMACY",
        "ABORTION",
        "CONTRACEPTIVES",
        "NEED_CERTIFICATES_TO_ADVERTISE_IN_CHINA",
        "KCDSP_REGISTRATION",
        "NOT_FAMILY_SAFE",
        "CLINICAL_TRIAL_RECRUITMENT",
        "MAXIMUM_NUMBER_OF_HTTP_CALLS_EXCEEDED",
        "MAXIMUM_NUMBER_OF_COOKIES_EXCEEDED",
        "PERSONAL_LOANS",
        "UNSUPPORTED_FLASH_CONTENT",
        "MISUSE_BY_OMID_SCRIPT",
        "NON_WHITELISTED_OMID_VENDOR",
        "DESTINATION_EXPERIENCE",
        "UNSUPPORTED_LANGUAGE",
        "NON_SSL_COMPLIANT",
        "TEMPORARY_PAUSE",
        "BAIL_BONDS",
        "EXPERIMENTAL_MEDICAL_TREATMENT",
    ]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FilterSet(typing_extensions.TypedDict, total=False):
    absoluteDateRange: AbsoluteDateRange
    breakdownDimensions: _list[str]
    creativeId: str
    dealId: str
    environment: typing_extensions.Literal["ENVIRONMENT_UNSPECIFIED", "WEB", "APP"]
    format: typing_extensions.Literal[
        "FORMAT_UNSPECIFIED",
        "NATIVE_DISPLAY",
        "NATIVE_VIDEO",
        "NON_NATIVE_DISPLAY",
        "NON_NATIVE_VIDEO",
    ]
    formats: _list[str]
    name: str
    platforms: _list[str]
    publisherIdentifiers: _list[str]
    realtimeTimeRange: RealtimeTimeRange
    relativeDateRange: RelativeDateRange
    sellerNetworkIds: _list[int]
    timeSeriesGranularity: typing_extensions.Literal[
        "TIME_SERIES_GRANULARITY_UNSPECIFIED", "HOURLY", "DAILY"
    ]

@typing.type_check_only
class FilteredBidCreativeRow(typing_extensions.TypedDict, total=False):
    bidCount: MetricValue
    creativeId: str
    rowDimensions: RowDimensions

@typing.type_check_only
class FilteredBidDetailRow(typing_extensions.TypedDict, total=False):
    bidCount: MetricValue
    detail: str
    detailId: int
    rowDimensions: RowDimensions

@typing.type_check_only
class FirstPartyMobileApplicationTargeting(typing_extensions.TypedDict, total=False):
    excludedAppIds: _list[str]
    targetedAppIds: _list[str]

@typing.type_check_only
class FrequencyCap(typing_extensions.TypedDict, total=False):
    maxImpressions: int
    numTimeUnits: int
    timeUnitType: typing_extensions.Literal[
        "TIME_UNIT_TYPE_UNSPECIFIED",
        "MINUTE",
        "HOUR",
        "DAY",
        "WEEK",
        "MONTH",
        "LIFETIME",
        "POD",
        "STREAM",
    ]

@typing.type_check_only
class GuaranteedFixedPriceTerms(typing_extensions.TypedDict, total=False):
    fixedPrices: _list[PricePerBuyer]
    guaranteedImpressions: str
    guaranteedLooks: str
    impressionCap: str
    minimumDailyLooks: str
    percentShareOfVoice: str
    reservationType: typing_extensions.Literal[
        "RESERVATION_TYPE_UNSPECIFIED", "STANDARD", "SPONSORSHIP"
    ]

@typing.type_check_only
class HtmlContent(typing_extensions.TypedDict, total=False):
    height: int
    snippet: str
    width: int

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    height: int
    url: str
    width: int

@typing.type_check_only
class ImpressionMetricsRow(typing_extensions.TypedDict, total=False):
    availableImpressions: MetricValue
    bidRequests: MetricValue
    inventoryMatches: MetricValue
    responsesWithBids: MetricValue
    rowDimensions: RowDimensions
    successfulResponses: MetricValue

@typing.type_check_only
class InventorySizeTargeting(typing_extensions.TypedDict, total=False):
    excludedInventorySizes: _list[AdSize]
    targetedInventorySizes: _list[AdSize]

@typing.type_check_only
class ListBidMetricsResponse(typing_extensions.TypedDict, total=False):
    bidMetricsRows: _list[BidMetricsRow]
    nextPageToken: str

@typing.type_check_only
class ListBidResponseErrorsResponse(typing_extensions.TypedDict, total=False):
    calloutStatusRows: _list[CalloutStatusRow]
    nextPageToken: str

@typing.type_check_only
class ListBidResponsesWithoutBidsResponse(typing_extensions.TypedDict, total=False):
    bidResponseWithoutBidsStatusRows: _list[BidResponseWithoutBidsStatusRow]
    nextPageToken: str

@typing.type_check_only
class ListClientUserInvitationsResponse(typing_extensions.TypedDict, total=False):
    invitations: _list[ClientUserInvitation]
    nextPageToken: str

@typing.type_check_only
class ListClientUsersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    users: _list[ClientUser]

@typing.type_check_only
class ListClientsResponse(typing_extensions.TypedDict, total=False):
    clients: _list[Client]
    nextPageToken: str

@typing.type_check_only
class ListCreativeStatusBreakdownByCreativeResponse(
    typing_extensions.TypedDict, total=False
):
    filteredBidCreativeRows: _list[FilteredBidCreativeRow]
    nextPageToken: str

@typing.type_check_only
class ListCreativeStatusBreakdownByDetailResponse(
    typing_extensions.TypedDict, total=False
):
    detailType: typing_extensions.Literal[
        "DETAIL_TYPE_UNSPECIFIED",
        "CREATIVE_ATTRIBUTE",
        "VENDOR",
        "SENSITIVE_CATEGORY",
        "PRODUCT_CATEGORY",
        "DISAPPROVAL_REASON",
        "POLICY_TOPIC",
        "ATP_VENDOR",
        "VENDOR_DOMAIN",
        "GVL_ID",
    ]
    filteredBidDetailRows: _list[FilteredBidDetailRow]
    nextPageToken: str

@typing.type_check_only
class ListCreativesResponse(typing_extensions.TypedDict, total=False):
    creatives: _list[Creative]
    nextPageToken: str

@typing.type_check_only
class ListDealAssociationsResponse(typing_extensions.TypedDict, total=False):
    associations: _list[CreativeDealAssociation]
    nextPageToken: str

@typing.type_check_only
class ListFilterSetsResponse(typing_extensions.TypedDict, total=False):
    filterSets: _list[FilterSet]
    nextPageToken: str

@typing.type_check_only
class ListFilteredBidRequestsResponse(typing_extensions.TypedDict, total=False):
    calloutStatusRows: _list[CalloutStatusRow]
    nextPageToken: str

@typing.type_check_only
class ListFilteredBidsResponse(typing_extensions.TypedDict, total=False):
    creativeStatusRows: _list[CreativeStatusRow]
    nextPageToken: str

@typing.type_check_only
class ListImpressionMetricsResponse(typing_extensions.TypedDict, total=False):
    impressionMetricsRows: _list[ImpressionMetricsRow]
    nextPageToken: str

@typing.type_check_only
class ListLosingBidsResponse(typing_extensions.TypedDict, total=False):
    creativeStatusRows: _list[CreativeStatusRow]
    nextPageToken: str

@typing.type_check_only
class ListNonBillableWinningBidsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    nonBillableWinningBidStatusRows: _list[NonBillableWinningBidStatusRow]

@typing.type_check_only
class ListProductsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    products: _list[Product]

@typing.type_check_only
class ListProposalsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    proposals: _list[Proposal]

@typing.type_check_only
class ListPublisherProfilesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    publisherProfiles: _list[PublisherProfile]

@typing.type_check_only
class LocationContext(typing_extensions.TypedDict, total=False):
    geoCriteriaIds: _list[int]

@typing.type_check_only
class MarketplaceTargeting(typing_extensions.TypedDict, total=False):
    geoTargeting: CriteriaTargeting
    inventorySizeTargeting: InventorySizeTargeting
    placementTargeting: PlacementTargeting
    technologyTargeting: TechnologyTargeting
    videoTargeting: VideoTargeting

@typing.type_check_only
class MetricValue(typing_extensions.TypedDict, total=False):
    value: str
    variance: str

@typing.type_check_only
class MobileApplicationTargeting(typing_extensions.TypedDict, total=False):
    firstPartyTargeting: FirstPartyMobileApplicationTargeting

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class NativeContent(typing_extensions.TypedDict, total=False):
    advertiserName: str
    appIcon: Image
    body: str
    callToAction: str
    clickLinkUrl: str
    clickTrackingUrl: str
    headline: str
    image: Image
    logo: Image
    priceDisplayText: str
    starRating: float
    storeUrl: str
    videoUrl: str

@typing.type_check_only
class NonBillableWinningBidStatusRow(typing_extensions.TypedDict, total=False):
    bidCount: MetricValue
    rowDimensions: RowDimensions
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "AD_NOT_RENDERED",
        "INVALID_IMPRESSION",
        "FATAL_VAST_ERROR",
        "LOST_IN_MEDIATION",
    ]

@typing.type_check_only
class NonGuaranteedAuctionTerms(typing_extensions.TypedDict, total=False):
    autoOptimizePrivateAuction: bool
    reservePricesPerBuyer: _list[PricePerBuyer]

@typing.type_check_only
class NonGuaranteedFixedPriceTerms(typing_extensions.TypedDict, total=False):
    fixedPrices: _list[PricePerBuyer]

@typing.type_check_only
class Note(typing_extensions.TypedDict, total=False):
    createTime: str
    creatorRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    note: str
    noteId: str
    proposalRevision: str

@typing.type_check_only
class OperatingSystemTargeting(typing_extensions.TypedDict, total=False):
    operatingSystemCriteria: CriteriaTargeting
    operatingSystemVersionCriteria: CriteriaTargeting

@typing.type_check_only
class PauseProposalDealsRequest(typing_extensions.TypedDict, total=False):
    externalDealIds: _list[str]
    reason: str

@typing.type_check_only
class PauseProposalRequest(typing_extensions.TypedDict, total=False):
    reason: str

@typing.type_check_only
class PlacementTargeting(typing_extensions.TypedDict, total=False):
    mobileApplicationTargeting: MobileApplicationTargeting
    urlTargeting: UrlTargeting

@typing.type_check_only
class PlatformContext(typing_extensions.TypedDict, total=False):
    platforms: _list[str]

@typing.type_check_only
class Price(typing_extensions.TypedDict, total=False):
    amount: Money
    pricingType: typing_extensions.Literal[
        "PRICING_TYPE_UNSPECIFIED", "COST_PER_MILLE", "COST_PER_DAY"
    ]

@typing.type_check_only
class PricePerBuyer(typing_extensions.TypedDict, total=False):
    advertiserIds: _list[str]
    buyer: Buyer
    price: Price

@typing.type_check_only
class PrivateData(typing_extensions.TypedDict, total=False):
    referenceId: str

@typing.type_check_only
class Product(typing_extensions.TypedDict, total=False):
    availableEndTime: str
    availableStartTime: str
    createTime: str
    creatorContacts: _list[ContactInformation]
    displayName: str
    hasCreatorSignedOff: bool
    productId: str
    productRevision: str
    publisherProfileId: str
    seller: Seller
    syndicationProduct: typing_extensions.Literal[
        "SYNDICATION_PRODUCT_UNSPECIFIED", "CONTENT", "MOBILE", "VIDEO", "GAMES"
    ]
    targetingCriterion: _list[TargetingCriteria]
    terms: DealTerms
    updateTime: str
    webPropertyCode: str

@typing.type_check_only
class Proposal(typing_extensions.TypedDict, total=False):
    billedBuyer: Buyer
    buyer: Buyer
    buyerContacts: _list[ContactInformation]
    buyerPrivateData: PrivateData
    deals: _list[Deal]
    displayName: str
    isRenegotiating: bool
    isSetupComplete: bool
    lastUpdaterOrCommentorRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    notes: _list[Note]
    originatorRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    privateAuctionId: str
    proposalId: str
    proposalRevision: str
    proposalState: typing_extensions.Literal[
        "PROPOSAL_STATE_UNSPECIFIED",
        "PROPOSED",
        "BUYER_ACCEPTED",
        "SELLER_ACCEPTED",
        "CANCELED",
        "FINALIZED",
    ]
    seller: Seller
    sellerContacts: _list[ContactInformation]
    termsAndConditions: str
    updateTime: str

@typing.type_check_only
class PublisherProfile(typing_extensions.TypedDict, total=False):
    audienceDescription: str
    buyerPitchStatement: str
    directDealsContact: str
    displayName: str
    domains: _list[str]
    googlePlusUrl: str
    isParent: bool
    logoUrl: str
    mediaKitUrl: str
    mobileApps: _list[PublisherProfileMobileApplication]
    overview: str
    programmaticDealsContact: str
    publisherProfileId: str
    rateCardInfoUrl: str
    samplePageUrl: str
    seller: Seller
    topHeadlines: _list[str]

@typing.type_check_only
class PublisherProfileMobileApplication(typing_extensions.TypedDict, total=False):
    appStore: typing_extensions.Literal[
        "APP_STORE_TYPE_UNSPECIFIED",
        "APPLE_ITUNES",
        "GOOGLE_PLAY",
        "ROKU",
        "AMAZON_FIRETV",
        "PLAYSTATION",
        "XBOX",
        "SAMSUNG_TV",
        "AMAZON",
        "OPPO",
        "SAMSUNG",
        "VIVO",
        "XIAOMI",
    ]
    externalAppId: str
    name: str

@typing.type_check_only
class RealtimeTimeRange(typing_extensions.TypedDict, total=False):
    startTimestamp: str

@typing.type_check_only
class RelativeDateRange(typing_extensions.TypedDict, total=False):
    durationDays: int
    offsetDays: int

@typing.type_check_only
class RemoveDealAssociationRequest(typing_extensions.TypedDict, total=False):
    association: CreativeDealAssociation

@typing.type_check_only
class ResumeProposalDealsRequest(typing_extensions.TypedDict, total=False):
    externalDealIds: _list[str]

@typing.type_check_only
class ResumeProposalRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RowDimensions(typing_extensions.TypedDict, total=False):
    publisherIdentifier: str
    timeInterval: TimeInterval

@typing.type_check_only
class SecurityContext(typing_extensions.TypedDict, total=False):
    securities: _list[str]

@typing.type_check_only
class Seller(typing_extensions.TypedDict, total=False):
    accountId: str
    subAccountId: str

@typing.type_check_only
class ServingContext(typing_extensions.TypedDict, total=False):
    all: typing_extensions.Literal["SIMPLE_CONTEXT"]
    appType: AppContext
    auctionType: AuctionContext
    location: LocationContext
    platform: PlatformContext
    securityType: SecurityContext

@typing.type_check_only
class ServingRestriction(typing_extensions.TypedDict, total=False):
    contexts: _list[ServingContext]
    disapproval: Disapproval
    disapprovalReasons: _list[Disapproval]
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED", "DISAPPROVAL", "PENDING_REVIEW"
    ]

@typing.type_check_only
class Size(typing_extensions.TypedDict, total=False):
    height: int
    width: int

@typing.type_check_only
class StopWatchingCreativeRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class TargetingCriteria(typing_extensions.TypedDict, total=False):
    exclusions: _list[TargetingValue]
    inclusions: _list[TargetingValue]
    key: str

@typing.type_check_only
class TargetingValue(typing_extensions.TypedDict, total=False):
    creativeSizeValue: CreativeSize
    dayPartTargetingValue: DayPartTargeting
    longValue: str
    stringValue: str

@typing.type_check_only
class TechnologyTargeting(typing_extensions.TypedDict, total=False):
    deviceCapabilityTargeting: CriteriaTargeting
    deviceCategoryTargeting: CriteriaTargeting
    operatingSystemTargeting: OperatingSystemTargeting

@typing.type_check_only
class TimeInterval(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class TimeOfDay(typing_extensions.TypedDict, total=False):
    hours: int
    minutes: int
    nanos: int
    seconds: int

@typing.type_check_only
class UrlTargeting(typing_extensions.TypedDict, total=False):
    excludedUrls: _list[str]
    targetedUrls: _list[str]

@typing.type_check_only
class VideoContent(typing_extensions.TypedDict, total=False):
    videoUrl: str
    videoVastXml: str

@typing.type_check_only
class VideoTargeting(typing_extensions.TypedDict, total=False):
    excludedPositionTypes: _list[str]
    targetedPositionTypes: _list[str]

@typing.type_check_only
class WatchCreativeRequest(typing_extensions.TypedDict, total=False):
    topic: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleApi__HttpBody(typing_extensions.TypedDict, total=False):
    contentType: str
    data: str
    extensions: _list[dict[str, typing.Any]]

@typing.type_check_only
class GoogleCloudMlV1_AutomatedStoppingConfig_DecayCurveAutomatedStoppingConfig(
    typing_extensions.TypedDict, total=False
):
    useElapsedTime: bool

@typing.type_check_only
class GoogleCloudMlV1_AutomatedStoppingConfig_MedianAutomatedStoppingConfig(
    typing_extensions.TypedDict, total=False
):
    useElapsedTime: bool

@typing.type_check_only
class GoogleCloudMlV1_HyperparameterOutput_HyperparameterMetric(
    typing_extensions.TypedDict, total=False
):
    objectiveValue: float
    trainingStep: str

@typing.type_check_only
class GoogleCloudMlV1_Measurement_Metric(typing_extensions.TypedDict, total=False):
    metric: str
    value: float

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_CategoricalValueSpec(
    typing_extensions.TypedDict, total=False
):
    values: _list[str]

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_DiscreteValueSpec(
    typing_extensions.TypedDict, total=False
):
    values: _list[float]

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_DoubleValueSpec(
    typing_extensions.TypedDict, total=False
):
    maxValue: float
    minValue: float

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_IntegerValueSpec(
    typing_extensions.TypedDict, total=False
):
    maxValue: str
    minValue: str

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_MatchingParentCategoricalValueSpec(
    typing_extensions.TypedDict, total=False
):
    values: _list[str]

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_MatchingParentDiscreteValueSpec(
    typing_extensions.TypedDict, total=False
):
    values: _list[float]

@typing.type_check_only
class GoogleCloudMlV1_StudyConfigParameterSpec_MatchingParentIntValueSpec(
    typing_extensions.TypedDict, total=False
):
    values: _list[str]

@typing.type_check_only
class GoogleCloudMlV1_StudyConfig_MetricSpec(typing_extensions.TypedDict, total=False):
    goal: typing_extensions.Literal["GOAL_TYPE_UNSPECIFIED", "MAXIMIZE", "MINIMIZE"]
    metric: str

@typing.type_check_only
class GoogleCloudMlV1_StudyConfig_ParameterSpec(
    typing_extensions.TypedDict, total=False
):
    categoricalValueSpec: GoogleCloudMlV1_StudyConfigParameterSpec_CategoricalValueSpec
    childParameterSpecs: _list[GoogleCloudMlV1_StudyConfig_ParameterSpec]
    discreteValueSpec: GoogleCloudMlV1_StudyConfigParameterSpec_DiscreteValueSpec
    doubleValueSpec: GoogleCloudMlV1_StudyConfigParameterSpec_DoubleValueSpec
    integerValueSpec: GoogleCloudMlV1_StudyConfigParameterSpec_IntegerValueSpec
    parameter: str
    parentCategoricalValues: GoogleCloudMlV1_StudyConfigParameterSpec_MatchingParentCategoricalValueSpec
    parentDiscreteValues: GoogleCloudMlV1_StudyConfigParameterSpec_MatchingParentDiscreteValueSpec
    parentIntValues: GoogleCloudMlV1_StudyConfigParameterSpec_MatchingParentIntValueSpec
    scaleType: typing_extensions.Literal[
        "SCALE_TYPE_UNSPECIFIED",
        "UNIT_LINEAR_SCALE",
        "UNIT_LOG_SCALE",
        "UNIT_REVERSE_LOG_SCALE",
    ]
    type: typing_extensions.Literal[
        "PARAMETER_TYPE_UNSPECIFIED", "DOUBLE", "INTEGER", "CATEGORICAL", "DISCRETE"
    ]

@typing.type_check_only
class GoogleCloudMlV1_Trial_Parameter(typing_extensions.TypedDict, total=False):
    floatValue: float
    intValue: str
    parameter: str
    stringValue: str

@typing.type_check_only
class GoogleCloudMlV1__AcceleratorConfig(typing_extensions.TypedDict, total=False):
    count: str
    type: typing_extensions.Literal[
        "ACCELERATOR_TYPE_UNSPECIFIED",
        "NVIDIA_TESLA_K80",
        "NVIDIA_TESLA_P100",
        "NVIDIA_TESLA_V100",
        "NVIDIA_TESLA_P4",
        "NVIDIA_TESLA_T4",
        "NVIDIA_TESLA_A100",
        "TPU_V2",
        "TPU_V3",
        "TPU_V2_POD",
        "TPU_V3_POD",
    ]

@typing.type_check_only
class GoogleCloudMlV1__AddTrialMeasurementRequest(
    typing_extensions.TypedDict, total=False
):
    measurement: GoogleCloudMlV1__Measurement

@typing.type_check_only
class GoogleCloudMlV1__AutoScaling(typing_extensions.TypedDict, total=False):
    maxNodes: int
    metrics: _list[GoogleCloudMlV1__MetricSpec]
    minNodes: int

@typing.type_check_only
class GoogleCloudMlV1__AutomatedStoppingConfig(
    typing_extensions.TypedDict, total=False
):
    decayCurveStoppingConfig: GoogleCloudMlV1_AutomatedStoppingConfig_DecayCurveAutomatedStoppingConfig
    medianAutomatedStoppingConfig: GoogleCloudMlV1_AutomatedStoppingConfig_MedianAutomatedStoppingConfig

@typing.type_check_only
class GoogleCloudMlV1__BuiltInAlgorithmOutput(typing_extensions.TypedDict, total=False):
    framework: str
    modelPath: str
    pythonVersion: str
    runtimeVersion: str

@typing.type_check_only
class GoogleCloudMlV1__CancelJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleCloudMlV1__Capability(typing_extensions.TypedDict, total=False):
    availableAccelerators: _list[str]
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "TRAINING", "BATCH_PREDICTION", "ONLINE_PREDICTION"
    ]

@typing.type_check_only
class GoogleCloudMlV1__CheckTrialEarlyStoppingStateMetatdata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    study: str
    trial: str

@typing.type_check_only
class GoogleCloudMlV1__CheckTrialEarlyStoppingStateRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudMlV1__CheckTrialEarlyStoppingStateResponse(
    typing_extensions.TypedDict, total=False
):
    endTime: str
    shouldStop: bool
    startTime: str

@typing.type_check_only
class GoogleCloudMlV1__CompleteTrialRequest(typing_extensions.TypedDict, total=False):
    finalMeasurement: GoogleCloudMlV1__Measurement
    infeasibleReason: str
    trialInfeasible: bool

@typing.type_check_only
class GoogleCloudMlV1__Config(typing_extensions.TypedDict, total=False):
    tpuServiceAccount: str

@typing.type_check_only
class GoogleCloudMlV1__ContainerPort(typing_extensions.TypedDict, total=False):
    containerPort: int

@typing.type_check_only
class GoogleCloudMlV1__ContainerSpec(typing_extensions.TypedDict, total=False):
    args: _list[str]
    command: _list[str]
    env: _list[GoogleCloudMlV1__EnvVar]
    image: str
    ports: _list[GoogleCloudMlV1__ContainerPort]

@typing.type_check_only
class GoogleCloudMlV1__DiskConfig(typing_extensions.TypedDict, total=False):
    bootDiskSizeGb: int
    bootDiskType: str

@typing.type_check_only
class GoogleCloudMlV1__EncryptionConfig(typing_extensions.TypedDict, total=False):
    kmsKeyName: str

@typing.type_check_only
class GoogleCloudMlV1__EnvVar(typing_extensions.TypedDict, total=False):
    name: str
    value: str

@typing.type_check_only
class GoogleCloudMlV1__ExplainRequest(typing_extensions.TypedDict, total=False):
    httpBody: GoogleApi__HttpBody

@typing.type_check_only
class GoogleCloudMlV1__ExplanationConfig(typing_extensions.TypedDict, total=False):
    integratedGradientsAttribution: GoogleCloudMlV1__IntegratedGradientsAttribution
    sampledShapleyAttribution: GoogleCloudMlV1__SampledShapleyAttribution
    xraiAttribution: GoogleCloudMlV1__XraiAttribution

@typing.type_check_only
class GoogleCloudMlV1__GetConfigResponse(typing_extensions.TypedDict, total=False):
    config: GoogleCloudMlV1__Config
    serviceAccount: str
    serviceAccountProject: str

@typing.type_check_only
class GoogleCloudMlV1__HyperparameterOutput(typing_extensions.TypedDict, total=False):
    allMetrics: _list[GoogleCloudMlV1_HyperparameterOutput_HyperparameterMetric]
    builtInAlgorithmOutput: GoogleCloudMlV1__BuiltInAlgorithmOutput
    endTime: str
    finalMetric: GoogleCloudMlV1_HyperparameterOutput_HyperparameterMetric
    hyperparameters: dict[str, typing.Any]
    isTrialStoppedEarly: bool
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "QUEUED",
        "PREPARING",
        "RUNNING",
        "SUCCEEDED",
        "FAILED",
        "CANCELLING",
        "CANCELLED",
    ]
    trialId: str
    webAccessUris: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudMlV1__HyperparameterSpec(typing_extensions.TypedDict, total=False):
    algorithm: typing_extensions.Literal[
        "ALGORITHM_UNSPECIFIED", "GRID_SEARCH", "RANDOM_SEARCH"
    ]
    enableTrialEarlyStopping: bool
    goal: typing_extensions.Literal["GOAL_TYPE_UNSPECIFIED", "MAXIMIZE", "MINIMIZE"]
    hyperparameterMetricTag: str
    maxFailedTrials: int
    maxParallelTrials: int
    maxTrials: int
    params: _list[GoogleCloudMlV1__ParameterSpec]
    resumePreviousJobId: str

@typing.type_check_only
class GoogleCloudMlV1__IntegratedGradientsAttribution(
    typing_extensions.TypedDict, total=False
):
    numIntegralSteps: int

@typing.type_check_only
class GoogleCloudMlV1__Job(typing_extensions.TypedDict, total=False):
    createTime: str
    endTime: str
    errorMessage: str
    etag: str
    jobId: str
    jobPosition: str
    labels: dict[str, typing.Any]
    predictionInput: GoogleCloudMlV1__PredictionInput
    predictionOutput: GoogleCloudMlV1__PredictionOutput
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "QUEUED",
        "PREPARING",
        "RUNNING",
        "SUCCEEDED",
        "FAILED",
        "CANCELLING",
        "CANCELLED",
    ]
    trainingInput: GoogleCloudMlV1__TrainingInput
    trainingOutput: GoogleCloudMlV1__TrainingOutput

@typing.type_check_only
class GoogleCloudMlV1__ListJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[GoogleCloudMlV1__Job]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudMlV1__ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[GoogleCloudMlV1__Location]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudMlV1__ListModelsResponse(typing_extensions.TypedDict, total=False):
    models: _list[GoogleCloudMlV1__Model]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudMlV1__ListOptimalTrialsRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudMlV1__ListOptimalTrialsResponse(
    typing_extensions.TypedDict, total=False
):
    trials: _list[GoogleCloudMlV1__Trial]

@typing.type_check_only
class GoogleCloudMlV1__ListStudiesResponse(typing_extensions.TypedDict, total=False):
    studies: _list[GoogleCloudMlV1__Study]

@typing.type_check_only
class GoogleCloudMlV1__ListTrialsResponse(typing_extensions.TypedDict, total=False):
    trials: _list[GoogleCloudMlV1__Trial]

@typing.type_check_only
class GoogleCloudMlV1__ListVersionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    versions: _list[GoogleCloudMlV1__Version]

@typing.type_check_only
class GoogleCloudMlV1__Location(typing_extensions.TypedDict, total=False):
    capabilities: _list[GoogleCloudMlV1__Capability]
    name: str

@typing.type_check_only
class GoogleCloudMlV1__ManualScaling(typing_extensions.TypedDict, total=False):
    nodes: int

@typing.type_check_only
class GoogleCloudMlV1__Measurement(typing_extensions.TypedDict, total=False):
    elapsedTime: str
    metrics: _list[GoogleCloudMlV1_Measurement_Metric]
    stepCount: str

@typing.type_check_only
class GoogleCloudMlV1__MetricSpec(typing_extensions.TypedDict, total=False):
    name: typing_extensions.Literal[
        "METRIC_NAME_UNSPECIFIED", "CPU_USAGE", "GPU_DUTY_CYCLE"
    ]
    target: int

@typing.type_check_only
class GoogleCloudMlV1__Model(typing_extensions.TypedDict, total=False):
    defaultVersion: GoogleCloudMlV1__Version
    description: str
    etag: str
    labels: dict[str, typing.Any]
    name: str
    onlinePredictionConsoleLogging: bool
    onlinePredictionLogging: bool
    regions: _list[str]

@typing.type_check_only
class GoogleCloudMlV1__OperationMetadata(typing_extensions.TypedDict, total=False):
    createTime: str
    endTime: str
    isCancellationRequested: bool
    labels: dict[str, typing.Any]
    modelName: str
    operationType: typing_extensions.Literal[
        "OPERATION_TYPE_UNSPECIFIED",
        "CREATE_VERSION",
        "DELETE_VERSION",
        "DELETE_MODEL",
        "UPDATE_MODEL",
        "UPDATE_VERSION",
        "UPDATE_CONFIG",
    ]
    projectNumber: str
    startTime: str
    version: GoogleCloudMlV1__Version

@typing.type_check_only
class GoogleCloudMlV1__ParameterSpec(typing_extensions.TypedDict, total=False):
    categoricalValues: _list[str]
    discreteValues: _list[float]
    maxValue: float
    minValue: float
    parameterName: str
    scaleType: typing_extensions.Literal[
        "NONE", "UNIT_LINEAR_SCALE", "UNIT_LOG_SCALE", "UNIT_REVERSE_LOG_SCALE"
    ]
    type: typing_extensions.Literal[
        "PARAMETER_TYPE_UNSPECIFIED", "DOUBLE", "INTEGER", "CATEGORICAL", "DISCRETE"
    ]

@typing.type_check_only
class GoogleCloudMlV1__PredictRequest(typing_extensions.TypedDict, total=False):
    httpBody: GoogleApi__HttpBody

@typing.type_check_only
class GoogleCloudMlV1__PredictionInput(typing_extensions.TypedDict, total=False):
    batchSize: str
    dataFormat: typing_extensions.Literal[
        "DATA_FORMAT_UNSPECIFIED", "JSON", "TEXT", "TF_RECORD", "TF_RECORD_GZIP", "CSV"
    ]
    inputPaths: _list[str]
    maxWorkerCount: str
    modelName: str
    outputDataFormat: typing_extensions.Literal[
        "DATA_FORMAT_UNSPECIFIED", "JSON", "TEXT", "TF_RECORD", "TF_RECORD_GZIP", "CSV"
    ]
    outputPath: str
    region: str
    runtimeVersion: str
    signatureName: str
    uri: str
    versionName: str

@typing.type_check_only
class GoogleCloudMlV1__PredictionOutput(typing_extensions.TypedDict, total=False):
    errorCount: str
    nodeHours: float
    outputPath: str
    predictionCount: str

@typing.type_check_only
class GoogleCloudMlV1__ReplicaConfig(typing_extensions.TypedDict, total=False):
    acceleratorConfig: GoogleCloudMlV1__AcceleratorConfig
    containerArgs: _list[str]
    containerCommand: _list[str]
    diskConfig: GoogleCloudMlV1__DiskConfig
    imageUri: str
    tpuTfVersion: str

@typing.type_check_only
class GoogleCloudMlV1__RequestLoggingConfig(typing_extensions.TypedDict, total=False):
    bigqueryTableName: str
    samplingPercentage: float

@typing.type_check_only
class GoogleCloudMlV1__RouteMap(typing_extensions.TypedDict, total=False):
    health: str
    predict: str

@typing.type_check_only
class GoogleCloudMlV1__SampledShapleyAttribution(
    typing_extensions.TypedDict, total=False
):
    numPaths: int

@typing.type_check_only
class GoogleCloudMlV1__Scheduling(typing_extensions.TypedDict, total=False):
    maxRunningTime: str
    maxWaitTime: str
    priority: int

@typing.type_check_only
class GoogleCloudMlV1__SetDefaultVersionRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudMlV1__StopTrialRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleCloudMlV1__Study(typing_extensions.TypedDict, total=False):
    createTime: str
    inactiveReason: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "INACTIVE", "COMPLETED"
    ]
    studyConfig: GoogleCloudMlV1__StudyConfig

@typing.type_check_only
class GoogleCloudMlV1__StudyConfig(typing_extensions.TypedDict, total=False):
    algorithm: typing_extensions.Literal[
        "ALGORITHM_UNSPECIFIED",
        "GAUSSIAN_PROCESS_BANDIT",
        "GRID_SEARCH",
        "RANDOM_SEARCH",
    ]
    automatedStoppingConfig: GoogleCloudMlV1__AutomatedStoppingConfig
    metrics: _list[GoogleCloudMlV1_StudyConfig_MetricSpec]
    parameters: _list[GoogleCloudMlV1_StudyConfig_ParameterSpec]

@typing.type_check_only
class GoogleCloudMlV1__SuggestTrialsMetadata(typing_extensions.TypedDict, total=False):
    clientId: str
    createTime: str
    study: str
    suggestionCount: int

@typing.type_check_only
class GoogleCloudMlV1__SuggestTrialsRequest(typing_extensions.TypedDict, total=False):
    clientId: str
    suggestionCount: int

@typing.type_check_only
class GoogleCloudMlV1__SuggestTrialsResponse(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str
    studyState: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "ACTIVE", "INACTIVE", "COMPLETED"
    ]
    trials: _list[GoogleCloudMlV1__Trial]

@typing.type_check_only
class GoogleCloudMlV1__TrainingInput(typing_extensions.TypedDict, total=False):
    args: _list[str]
    enableWebAccess: bool
    encryptionConfig: GoogleCloudMlV1__EncryptionConfig
    evaluatorConfig: GoogleCloudMlV1__ReplicaConfig
    evaluatorCount: str
    evaluatorType: str
    hyperparameters: GoogleCloudMlV1__HyperparameterSpec
    jobDir: str
    masterConfig: GoogleCloudMlV1__ReplicaConfig
    masterType: str
    network: str
    packageUris: _list[str]
    parameterServerConfig: GoogleCloudMlV1__ReplicaConfig
    parameterServerCount: str
    parameterServerType: str
    pythonModule: str
    pythonVersion: str
    region: str
    runtimeVersion: str
    scaleTier: typing_extensions.Literal[
        "BASIC", "STANDARD_1", "PREMIUM_1", "BASIC_GPU", "BASIC_TPU", "CUSTOM"
    ]
    scheduling: GoogleCloudMlV1__Scheduling
    serviceAccount: str
    useChiefInTfConfig: bool
    workerConfig: GoogleCloudMlV1__ReplicaConfig
    workerCount: str
    workerType: str

@typing.type_check_only
class GoogleCloudMlV1__TrainingOutput(typing_extensions.TypedDict, total=False):
    builtInAlgorithmOutput: GoogleCloudMlV1__BuiltInAlgorithmOutput
    completedTrialCount: str
    consumedMLUnits: float
    hyperparameterMetricTag: str
    isBuiltInAlgorithmJob: bool
    isHyperparameterTuningJob: bool
    trials: _list[GoogleCloudMlV1__HyperparameterOutput]
    webAccessUris: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudMlV1__Trial(typing_extensions.TypedDict, total=False):
    clientId: str
    endTime: str
    finalMeasurement: GoogleCloudMlV1__Measurement
    infeasibleReason: str
    measurements: _list[GoogleCloudMlV1__Measurement]
    name: str
    parameters: _list[GoogleCloudMlV1_Trial_Parameter]
    startTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "REQUESTED", "ACTIVE", "COMPLETED", "STOPPING"
    ]
    trialInfeasible: bool

@typing.type_check_only
class GoogleCloudMlV1__Version(typing_extensions.TypedDict, total=False):
    acceleratorConfig: GoogleCloudMlV1__AcceleratorConfig
    autoScaling: GoogleCloudMlV1__AutoScaling
    container: GoogleCloudMlV1__ContainerSpec
    createTime: str
    deploymentUri: str
    description: str
    errorMessage: str
    etag: str
    explanationConfig: GoogleCloudMlV1__ExplanationConfig
    framework: typing_extensions.Literal[
        "FRAMEWORK_UNSPECIFIED", "TENSORFLOW", "SCIKIT_LEARN", "XGBOOST"
    ]
    isDefault: bool
    labels: dict[str, typing.Any]
    lastMigrationModelId: str
    lastMigrationTime: str
    lastUseTime: str
    machineType: str
    manualScaling: GoogleCloudMlV1__ManualScaling
    name: str
    packageUris: _list[str]
    predictionClass: str
    pythonVersion: str
    requestLoggingConfig: GoogleCloudMlV1__RequestLoggingConfig
    routes: GoogleCloudMlV1__RouteMap
    runtimeVersion: str
    serviceAccount: str
    state: typing_extensions.Literal[
        "UNKNOWN", "READY", "CREATING", "FAILED", "DELETING", "UPDATING"
    ]

@typing.type_check_only
class GoogleCloudMlV1__XraiAttribution(typing_extensions.TypedDict, total=False):
    numIntegralSteps: int

@typing.type_check_only
class GoogleIamV1__AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[GoogleIamV1__AuditLogConfig]
    service: str

@typing.type_check_only
class GoogleIamV1__AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class GoogleIamV1__Binding(typing_extensions.TypedDict, total=False):
    condition: GoogleType__Expr
    members: _list[str]
    role: str

@typing.type_check_only
class GoogleIamV1__Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[GoogleIamV1__AuditConfig]
    bindings: _list[GoogleIamV1__Binding]
    etag: str
    version: int

@typing.type_check_only
class GoogleIamV1__SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: GoogleIamV1__Policy
    updateMask: str

@typing.type_check_only
class GoogleIamV1__TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleIamV1__TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleLongrunning__ListOperationsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    operations: _list[GoogleLongrunning__Operation]

@typing.type_check_only
class GoogleLongrunning__Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpc__Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleProtobuf__Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleRpc__Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class GoogleType__Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleSearchIdeahubV1betaAvailableLocale(
    typing_extensions.TypedDict, total=False
):
    locale: str
    name: str

@typing.type_check_only
class GoogleSearchIdeahubV1betaIdea(typing_extensions.TypedDict, total=False):
    name: str
    text: str
    topics: _list[GoogleSearchIdeahubV1betaTopic]

@typing.type_check_only
class GoogleSearchIdeahubV1betaIdeaActivity(typing_extensions.TypedDict, total=False):
    ideas: _list[str]
    name: str
    topics: _list[str]
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "POST_DRAFTED",
        "POST_PUBLISHED",
        "POST_DELETED",
        "POST_UNPUBLISHED",
    ]
    uri: str

@typing.type_check_only
class GoogleSearchIdeahubV1betaIdeaState(typing_extensions.TypedDict, total=False):
    dismissed: bool
    name: str
    saved: bool

@typing.type_check_only
class GoogleSearchIdeahubV1betaListAvailableLocalesResponse(
    typing_extensions.TypedDict, total=False
):
    availableLocales: _list[GoogleSearchIdeahubV1betaAvailableLocale]
    nextPageToken: str

@typing.type_check_only
class GoogleSearchIdeahubV1betaListIdeasResponse(
    typing_extensions.TypedDict, total=False
):
    ideas: _list[GoogleSearchIdeahubV1betaIdea]
    nextPageToken: str

@typing.type_check_only
class GoogleSearchIdeahubV1betaTopic(typing_extensions.TypedDict, total=False):
    displayName: str
    mid: str
    name: str

@typing.type_check_only
class GoogleSearchIdeahubV1betaTopicState(typing_extensions.TypedDict, total=False):
    dismissed: bool
    name: str
    saved: bool



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ReportsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ActivitiesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            userKey: str,
            applicationName: typing_extensions.Literal[
                "access_transparency",
                "admin",
                "calendar",
                "chat",
                "drive",
                "gcp",
                "gplus",
                "groups",
                "groups_enterprise",
                "jamboard",
                "login",
                "meet",
                "mobile",
                "rules",
                "saml",
                "token",
                "user_accounts",
                "context_aware_access",
                "chrome",
                "data_studio",
                "keep",
            ],
            actorIpAddress: str = ...,
            customerId: str = ...,
            endTime: str = ...,
            eventName: str = ...,
            filters: str = ...,
            groupIdFilter: str = ...,
            maxResults: int = ...,
            orgUnitID: str = ...,
            pageToken: str = ...,
            startTime: str = ...,
            **kwargs: typing.Any
        ) -> ActivitiesHttpRequest: ...
        def list_next(
            self, previous_request: ActivitiesHttpRequest, previous_response: Activities
        ) -> ActivitiesHttpRequest | None: ...
        def watch(
            self,
            *,
            userKey: str,
            applicationName: typing_extensions.Literal[
                "access_transparency",
                "admin",
                "calendar",
                "chat",
                "drive",
                "gcp",
                "gplus",
                "groups",
                "groups_enterprise",
                "jamboard",
                "login",
                "meet",
                "mobile",
                "rules",
                "saml",
                "token",
                "user_accounts",
                "context_aware_access",
                "chrome",
                "data_studio",
                "keep",
            ],
            body: Channel = ...,
            actorIpAddress: str = ...,
            customerId: str = ...,
            endTime: str = ...,
            eventName: str = ...,
            filters: str = ...,
            groupIdFilter: str = ...,
            maxResults: int = ...,
            orgUnitID: str = ...,
            pageToken: str = ...,
            startTime: str = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...

    @typing.type_check_only
    class ChannelsResource(googleapiclient.discovery.Resource):
        def stop(
            self, *, body: Channel = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class CustomerUsageReportsResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            date: str,
            customerId: str = ...,
            pageToken: str = ...,
            parameters: str = ...,
            **kwargs: typing.Any
        ) -> UsageReportsHttpRequest: ...
        def get_next(
            self,
            previous_request: UsageReportsHttpRequest,
            previous_response: UsageReports,
        ) -> UsageReportsHttpRequest | None: ...

    @typing.type_check_only
    class EntityUsageReportsResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            entityType: typing_extensions.Literal["gplus_communities"],
            entityKey: str,
            date: str,
            customerId: str = ...,
            filters: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            parameters: str = ...,
            **kwargs: typing.Any
        ) -> UsageReportsHttpRequest: ...
        def get_next(
            self,
            previous_request: UsageReportsHttpRequest,
            previous_response: UsageReports,
        ) -> UsageReportsHttpRequest | None: ...

    @typing.type_check_only
    class UserUsageReportResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            userKey: str,
            date: str,
            customerId: str = ...,
            filters: str = ...,
            groupIdFilter: str = ...,
            maxResults: int = ...,
            orgUnitID: str = ...,
            pageToken: str = ...,
            parameters: str = ...,
            **kwargs: typing.Any
        ) -> UsageReportsHttpRequest: ...
        def get_next(
            self,
            previous_request: UsageReportsHttpRequest,
            previous_response: UsageReports,
        ) -> UsageReportsHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def activities(self) -> ActivitiesResource: ...
    def channels(self) -> ChannelsResource: ...
    def customerUsageReports(self) -> CustomerUsageReportsResource: ...
    def entityUsageReports(self) -> EntityUsageReportsResource: ...
    def userUsageReport(self) -> UserUsageReportResource: ...

@typing.type_check_only
class ActivitiesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Activities: ...

@typing.type_check_only
class ChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Channel: ...

@typing.type_check_only
class UsageReportsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UsageReports: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SemanticTileResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FeaturetilesResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            name: str,
            alwaysIncludeBuildingFootprints: bool = ...,
            clientInfo_apiClient: str = ...,
            clientInfo_applicationId: str = ...,
            clientInfo_applicationVersion: str = ...,
            clientInfo_deviceModel: str = ...,
            clientInfo_operatingSystem: str = ...,
            clientInfo_platform: typing_extensions.Literal[
                "PLATFORM_UNSPECIFIED",
                "EDITOR",
                "MAC_OS",
                "WINDOWS",
                "LINUX",
                "ANDROID",
                "IOS",
                "WEB_GL",
            ] = ...,
            clientInfo_userId: str = ...,
            clientTileVersionId: str = ...,
            enableDetailedHighwayTypes: bool = ...,
            enableFeatureNames: bool = ...,
            enableModeledVolumes: bool = ...,
            enablePoliticalFeatures: bool = ...,
            enablePrivateRoads: bool = ...,
            enableUnclippedBuildings: bool = ...,
            languageCode: str = ...,
            regionCode: str = ...,
            **kwargs: typing.Any
        ) -> FeatureTileHttpRequest: ...

    @typing.type_check_only
    class TerraintilesResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            name: str,
            altitudePrecisionCentimeters: int = ...,
            clientInfo_apiClient: str = ...,
            clientInfo_applicationId: str = ...,
            clientInfo_applicationVersion: str = ...,
            clientInfo_deviceModel: str = ...,
            clientInfo_operatingSystem: str = ...,
            clientInfo_platform: typing_extensions.Literal[
                "PLATFORM_UNSPECIFIED",
                "EDITOR",
                "MAC_OS",
                "WINDOWS",
                "LINUX",
                "ANDROID",
                "IOS",
                "WEB_GL",
            ] = ...,
            clientInfo_userId: str = ...,
            maxElevationResolutionCells: int = ...,
            minElevationResolutionCells: int = ...,
            terrainFormats: typing_extensions.Literal[
                "TERRAIN_FORMAT_UNKNOWN", "FIRST_DERIVATIVE", "SECOND_DERIVATIVE"
            ]
            | _list[
                typing_extensions.Literal[
                    "TERRAIN_FORMAT_UNKNOWN", "FIRST_DERIVATIVE", "SECOND_DERIVATIVE"
                ]
            ] = ...,
            **kwargs: typing.Any
        ) -> TerrainTileHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def featuretiles(self) -> FeaturetilesResource: ...
    def terraintiles(self) -> TerraintilesResource: ...

@typing.type_check_only
class FeatureTileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FeatureTile: ...

@typing.type_check_only
class TerrainTileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TerrainTile: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Bin(typing_extensions.TypedDict, total=False):
    density: float
    end: typing.Any
    start: typing.Any

@typing.type_check_only
class CollectionPeriod(typing_extensions.TypedDict, total=False):
    firstDate: Date
    lastDate: Date

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class Key(typing_extensions.TypedDict, total=False):
    effectiveConnectionType: str
    formFactor: typing_extensions.Literal[
        "ALL_FORM_FACTORS", "PHONE", "DESKTOP", "TABLET"
    ]
    origin: str
    url: str

@typing.type_check_only
class Metric(typing_extensions.TypedDict, total=False):
    histogram: _list[Bin]
    percentiles: Percentiles

@typing.type_check_only
class Percentiles(typing_extensions.TypedDict, total=False):
    p75: typing.Any

@typing.type_check_only
class QueryRequest(typing_extensions.TypedDict, total=False):
    effectiveConnectionType: str
    formFactor: typing_extensions.Literal[
        "ALL_FORM_FACTORS", "PHONE", "DESKTOP", "TABLET"
    ]
    metrics: _list[str]
    origin: str
    url: str

@typing.type_check_only
class QueryResponse(typing_extensions.TypedDict, total=False):
    record: Record
    urlNormalizationDetails: UrlNormalization

@typing.type_check_only
class Record(typing_extensions.TypedDict, total=False):
    collectionPeriod: CollectionPeriod
    key: Key
    metrics: dict[str, typing.Any]

@typing.type_check_only
class UrlNormalization(typing_extensions.TypedDict, total=False):
    normalizedUrl: str
    originalUrl: str
